-- Available clip colors
Colors = {[1]="Cream", [2]="Cocoa", [3]="Sand", [4] = "Lemon", [5] = "Mint", [6] = "Sky", [7] = "Lavender", [8] = "Rose", [9] = "Fuchsia", [10] = "Purple", [11] = "Pink", [12] = "Red", [13] = "Yellow", [14] = "Green", [15] = "Cyan", [16] = "Blue"}

-- Will be populated with Multicam angles
Angles = {}

-- Project variables
projMan = Resolve():GetProjectManager()
curProj = projMan:GetCurrentProject()
curTimeline = curProj:GetCurrentTimeline()
numTracks = curTimeline:GetTrackCount("video")

-- Iterate through each video track
for i=1, numTracks do -- track loop
	
	trackItems = curTimeline:GetItemListInTrack("video",i)
	
	-- iterate through each video item on the current track
	for i, item in ipairs(trackItems) do -- track item loop
		
		--remove any marker colors already existing in the clip from the available pool of marker colors to tag multicam angles with. To avoid confusion when using filters in the color page.
		Markers = item:GetMarkers()
		if Markers ~= nil then
			for m, v in pairs(Markers) do --iterate through each marker on the clip
			customData =  v.customData
			if (customData == "Multicam Angle") then
				item:DeleteMarkerAtFrame(m)
			else
				for c, n in pairs(Colors) do -- find the matching color in the Colors list and remove it from the pool
					if n == v.color then
						table.remove(Colors,c)
						break
						end-- if matching color
					end -- for loop matching color
				end-- if matching customData
			end-- for loop markers
		end
		
		-- check if the current clip is a multicam source
		MediaPoolItem = item:GetMediaPoolItem()
		if MediaPoolItem == nil then goto continue end
		typeCheck = MediaPoolItem:GetClipProperty("type")
		if typeCheck == "Multicam" then -- multicam check
			
			-- get name of the active angle of the current multicam clip
			itemName = item:GetName()
			angleName = string.sub(itemName,string.find(itemName, "-[^-]*$")+2,-1)
			
			-- add multicam angle name to Angles table if not already there. Then add the current timeline item as a child of that angle.
			if Angles[angleName] == nil then
				Angles[angleName] = {}
			end
			table.insert(Angles[angleName], item)
		end -- multicam check
		::continue:: -- go to here if item does not have a media pool source
	end -- track item loop
	
end -- track loop

-- Iterate through the Angle table entries and assign a unique color for all timeline items within each angle name
ColorIndex = 1
for name, items in pairs(Angles) do -- angle loop
 	for i in ipairs(items) do
 		frameIn = items[i]:GetLeftOffset()+1
 		items[i]:AddMarker(frameIn, Colors[ColorIndex], name, "auto-generated with Mark Multicam Angles.lua script", 1, "Multicam Angle")
 	end
 	if ColorIndex == #Colors then -- reset color index if at last color
 		ColorIndex = 1
 	else
 		ColorIndex = ColorIndex + 1 -- increment color index for the next angle
 	end
end -- angle loop